@@ -13,7 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use Kernel::Language              qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -42,7 +42,7 @@ sub Run {
 
     my $CommunicationType = IsStringWithData($Operation) ? 'Provider'  : 'Requester';
     my $ActionType        = IsStringWithData($Operation) ? 'Operation' : 'Invoker';
-    my $Action = $Operation || $Invoker;
+    my $Action            = $Operation || $Invoker;
 
     # Set mapping direction for display.
     my $MappingDirection = $Direction eq 'MappingOutbound'
@@ -123,6 +123,8 @@ sub Run {
 
         $Mapping{Template}              = $MappingConfig->{Template};
         $Mapping{DataInclude}           = $MappingConfig->{DataInclude};
+        $Mapping{ForceArray}            = $MappingConfig->{ForceArray};
+        $Mapping{KeepAttributes}        = $MappingConfig->{KeepAttributes};
         $Mapping{PreRegExFilter}        = $MappingConfig->{PreRegExFilter};
         $Mapping{PreRegExValueCounter}  = $MappingConfig->{PreRegExValueCounter};
         $Mapping{PostRegExFilter}       = $MappingConfig->{PostRegExFilter};
@@ -172,12 +174,15 @@ sub Run {
                 Action               => $Action,
                 ActionFrontendModule => $ActionFrontendModule,
                 Subaction            => 'Change',
+                TemplateError        => $GetParam->{Error}->{Template} ? 1 : 0,
             );
         }
 
         my %NewMapping;
         $NewMapping{Template}              = $GetParam->{Template};
         $NewMapping{DataInclude}           = $GetParam->{DataInclude};
+        $NewMapping{ForceArray}            = $GetParam->{ForceArray};
+        $NewMapping{KeepAttributes}        = $GetParam->{KeepAttributes};
         $NewMapping{PreRegExFilter}        = $GetParam->{PreRegExFilter};
         $NewMapping{PreRegExValueCounter}  = $GetParam->{PreRegExValueCounter};
         $NewMapping{PostRegExFilter}       = $GetParam->{PostRegExFilter};
@@ -254,6 +259,13 @@ sub _ShowEdit {
     my $Output = $LayoutObject->Header();
     $Output .= $LayoutObject->NavigationBar();
 
+    if ( $Param{TemplateError} ) {
+        $Output .= $LayoutObject->Notify(
+            Priority => 'Error',
+            Info     => Translatable('The entered data is not a valid XSLT style sheet.'),
+        );
+    }
+
     my $MappingConfig = $Param{WebserviceData};
     my %Error;
     if ( defined $Param{WebserviceData}->{Error} ) {
@@ -308,7 +320,7 @@ sub _ShowEdit {
                     Value => Translatable('Incoming response data before mapping (RequesterResponseInput)'),
                 },
                 {
-                    Key => 'RequesterErrorHandlingOutput',
+                    Key   => 'RequesterErrorHandlingOutput',
                     Value =>
                         Translatable('Outgoing error handler data after error handling (RequesterErrorHandlingOutput)'),
                 },
@@ -329,7 +341,7 @@ sub _ShowEdit {
                     Value => Translatable('Outgoing response data before mapping (ProviderResponseInput)'),
                 },
                 {
-                    Key => 'ProviderErrorHandlingOutput',
+                    Key   => 'ProviderErrorHandlingOutput',
                     Value =>
                         Translatable('Outgoing error handler data after error handling (ProviderErrorHandlingOutput)'),
                 },
@@ -352,6 +364,9 @@ sub _ShowEdit {
         Class        => 'Modernize W50pc',
     );
 
+    $Param{ForceArray}     = $MappingConfig->{ForceArray}     // '';
+    $Param{KeepAttributes} = $MappingConfig->{KeepAttributes} // '';
+
     $LayoutObject->Block(
         Name => 'ConfigBlock',
         Data => {},
@@ -385,6 +400,8 @@ sub _ShowEdit {
 sub _GetParams {
     my ( $Self, %Param ) = @_;
 
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my $GetParam;
 
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
@@ -394,6 +411,10 @@ sub _GetParams {
     my @DataInclude = $ParamObject->GetArray( Param => 'DataInclude' );
     $GetParam->{DataInclude} = \@DataInclude;
 
+    $GetParam->{ForceArray}     = $ParamObject->GetParam( Param => 'ForceArray' )     // '';
+    $GetParam->{KeepAttributes} = $ParamObject->GetParam( Param => 'KeepAttributes' ) // '';
+    my $LibXMLHugeXMLDataSupportEnabled = $ConfigObject->Get('LibXML::EnableHugeXMLDataSupport') ? 1 : 0;
+
     # Check validity.
     my $LibXML  = XML::LibXML->new();
     my $LibXSLT = XML::LibXSLT->new();
@@ -402,6 +423,7 @@ sub _GetParams {
         $StyleDoc = XML::LibXML->load_xml(
             string   => $GetParam->{Template},
             no_cdata => 1,
+            huge     => $LibXMLHugeXMLDataSupportEnabled,
         );
     };
     if ( !$StyleDoc ) {
