@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use Kernel::Language              qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -37,6 +37,7 @@ sub Run {
 
     my $SystemMaintenanceID = $ParamObject->GetParam( Param => 'SystemMaintenanceID' ) || '';
     my $WantSessionID       = $ParamObject->GetParam( Param => 'WantSessionID' )       || '';
+    my $Notification        = $ParamObject->GetParam( Param => 'Notification' )        || '';
 
     my $SessionVisibility = 'Collapsed';
 
@@ -239,7 +240,7 @@ sub Run {
             );
         }
 
-        if ( $ParamObject->GetParam( Param => 'Notification' ) eq 'Add' ) {
+        if ( $Notification eq 'Add' ) {
 
             # add notification
             push @NotifyData, {
@@ -248,7 +249,7 @@ sub Run {
             };
         }
 
-        if ( $ParamObject->GetParam( Param => 'Notification' ) eq 'Update' ) {
+        if ( $Notification eq 'Update' ) {
 
             # add notification
             push @NotifyData, {
@@ -484,12 +485,12 @@ sub Run {
         my $Output = $LayoutObject->Header();
         $Output .= $LayoutObject->NavigationBar();
 
-        if ( ( $ParamObject->GetParam( Param => 'Notification' ) || '' ) eq 'Update' ) {
+        if ( $Notification eq 'Update' ) {
             $Output .= $LayoutObject->Notify(
                 Info => Translatable('System Maintenance was updated successfully!')
             );
         }
-        elsif ( ( $ParamObject->GetParam( Param => 'Notification' ) || '' ) eq 'Add' ) {
+        elsif ( $Notification eq 'Add' ) {
             $Output .= $LayoutObject->Notify(
                 Info => Translatable('System Maintenance was added successfully!')
             );
