@@ -37,24 +37,8 @@ sub Run {
 
     my @Tasks = (
         {
-            Message => 'Increase size of columns of database table search_profile.',
-            Module  => 'SearchProfile',
-        },
-        {
-            Message => 'Create new communication channel Web.',
-            Module  => 'CreateCommunicationChannelWeb',
-        },
-        {
-            Message => 'Create database table translation.',
-            Module  => 'Translation',
-        },
-        {
-            Message => 'Create database table article_color.',
-            Module  => 'ArticleColor',
-        },
-        {
-            Message => 'Create table for user process preferences support.',
-            Module  => 'ProcessPreferences',
+            Message => 'Create database table sendmail_config.',
+            Module  => 'SendmailConfig',
         },
     );
 
